@@ -2,7 +2,7 @@
  * Copyright (C) 2017 Damir Porobic <https://github.com/damirporobic>
  *
  * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
+ * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
  *
@@ -11,7 +11,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public License
+ * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301, USA.
@@ -19,15 +19,20 @@
 
 #include "IconLoader.h"
 
-QIcon IconLoader::load(QString name)
+QIcon IconLoader::load(const QString &name)
+{
+	return QIcon(QLatin1Literal(":/icons/") + name);
+}
+
+QIcon IconLoader::loadForTheme(const QString& name)
 {
     auto type = getThemePrefix();
-    return QIcon(QStringLiteral(":/icons/") + type + name);
+    return QIcon(QLatin1Literal(":/icons/") + type + name);
 }
 
 QString IconLoader::getThemePrefix()
 {
-    return isDarkTheme() ? QStringLiteral("dark/") : QStringLiteral("light/");
+    return isDarkTheme() ? QLatin1Literal("dark/") : QLatin1Literal("light/");
 }
 
 double IconLoader::getThemeLuma()
