@@ -2,7 +2,7 @@
  *  Copyright (C) 2016 Damir Porobic <https://github.com/damirporobic>
  *
  * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
+ * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
  *
@@ -11,7 +11,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public License
+ * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301, USA.
@@ -25,41 +25,46 @@
 
 #include <functional>
 
-#include <kImageAnnotator/KImageAnnotator.h>
-
-#include "gui/aboutDialog/AboutDialog.h"
+#include "src/gui/TrayIcon.h"
+#include "src/gui/imageAnnotator/KImageAnnotatorAdapter.h"
+#include "src/gui/aboutDialog/AboutDialog.h"
 #include "src/gui/settingsDialog/SettingsDialog.h"
-#include "src/widgets/CustomToolButton.h"
+#include "src/gui/operations/AddWatermarkOperation.h"
+#include "src/gui/operations/UploadOperation.h"
+#include "src/gui/operations/HandleUploadResultOperation.h"
+#include "src/gui/globalHotKeys/GlobalHotKeyHandler.h"
+#include "src/gui/captureHandler/CaptureHandlerFactory.h"
+#include "src/gui/captureHandler/ICaptureChangeListener.h"
+#include "src/gui/widgetVisibilityHandler/WidgetVisibilityHandlerFactory.h"
+#include "src/gui/pinWindow/PinWindowHandler.h"
+#include "src/gui/serviceLocator/ServiceLocator.h"
 #include "src/widgets/MainToolBar.h"
 #include "src/backend/imageGrabber/AbstractImageGrabber.h"
 #include "src/backend/config/KsnipConfigProvider.h"
-#include "src/backend/uploader/CaptureUploader.h"
+#include "src/backend/uploader/UploaderProvider.h"
 #include "src/backend/CapturePrinter.h"
 #include "src/common/loader/IconLoader.h"
 #include "src/common/enum/RunMode.h"
-#include "src/gui/operations/SaveOperation.h"
-#include "src/gui/operations/AddWatermarkOperation.h"
-#include "src/gui/operations/CanDiscardOperation.h"
-#include "src/gui/operations/UploadOperation.h"
-#include "src/gui/operations/HandleUploadResponseOperation.h"
-#include "src/gui/globalHotKeys/GlobalHotKeyHandler.h"
-#include "src/gui/TrayIcon.h"
+#include "src/common/provider/ApplicationTitleProvider.h"
+#include "src/common/dtos/CaptureFromFileDto.h"
+#include "src/common/handler/DragAndDropHandler.h"
+#include "src/common/adapter/fileDialog/FileDialogAdapterFactory.h"
 
-using kImageAnnotator::KImageAnnotator;
-
-class MainWindow : public QMainWindow
+class MainWindow : public QMainWindow, public ICaptureChangeListener
 {
     Q_OBJECT
 public:
     explicit MainWindow(AbstractImageGrabber *imageGrabber, RunMode mode = RunMode::GUI);
     ~MainWindow() override;
     void showEmpty();
-    void show();
+	void showHidden();
+    void showDefault();
     void captureScreenshot(CaptureModes captureMode, bool captureCursor, int delay);
+	void resizeToAnnotator();
 
 public slots:
-    void showCapture(const CaptureDto &capture);
-	void triggerNewCapture(CaptureModes captureMode);
+    void processCapture(const CaptureDto &capture);
+	void processImage(const CaptureDto &capture);
 	void quit();
 
 protected:
@@ -72,59 +77,77 @@ protected:
 private:
     AbstractImageGrabber *mImageGrabber;
     RunMode mMode;
-    bool mIsUnsaved;
-    bool mHidden;
-    Qt::WindowState mSelectedWindowState;
-    bool mWindowStateChangeLock;
-    QAction *mUploadToImgurAction;
+    bool mSessionManagerRequestedQuit;
+    QAction *mSaveAsAction;
+    QAction *mUploadAction;
     QAction *mPrintAction;
     QAction *mPrintPreviewAction;
     QAction *mQuitAction;
-    QAction *mSettingsDialogAction;
+    QAction *mCopyPathAction;
+    QAction *mRenameAction;
+    QAction *mOpenDirectoryAction;
+    QAction *mSettingsAction;
     QAction *mAboutAction;
     QAction *mOpenImageAction;
     QAction *mScaleAction;
     QAction *mAddWatermarkAction;
+    QAction *mPasteAction;
+    QAction *mPasteEmbeddedAction;
+    QAction *mPinAction;
+    QAction *mRemoveImageAction;
     MainToolBar *mToolBar;
-    QClipboard *mClipboard;
+    QLayout *mMainLayout;
     KsnipConfig *mConfig;
-    CapturePrinter *mCapturePrinter;
-    CaptureUploader *mCaptureUploader;
-    KImageAnnotator *mKImageAnnotator;
+	IServiceLocator *mServiceLocator;
+	IClipboard *mClipboard;
+	CapturePrinter *mCapturePrinter;
+    IImageAnnotator *mImageAnnotator;
     SavePathProvider mSavePathProvider;
     GlobalHotKeyHandler *mGlobalHotKeyHandler;
     TrayIcon *mTrayIcon;
+	DragAndDropHandler *mDragAndDropHandler;
+	UploaderProvider *mUploaderProvider;
+	ICaptureHandler *mCaptureHandler;
+	PinWindowHandler *mPinWindowHandler;
+	WidgetVisibilityHandler *mVisibilityHandler;
+	IFileDialogAdapter *mFileDialog;
 
-    void setSaveable(bool enabled);
     void setEnablements(bool enabled);
     void loadSettings();
-    void setHidden(bool isHidden);
-    bool hidden() const;
     void capture(CaptureModes captureMode);
     void initGui();
-	void loadCapture(const CaptureDto &capture);
 	void processInstantCapture(const CaptureDto &capture);
 	void showDialog(const std::function<void ()>& showDialogMethod);
 
 private slots:
-    void saveCapture();
+	void captureChanged() override;
+	void captureEmpty() override;
     void copyCaptureToClipboard();
     void upload();
-    void uploadFinished(const QString &response);
+    void uploadFinished(const UploadResult &result);
     void printClicked();
     void printPreviewClicked();
-    void instantSave();
-    void loadImageFromFile();
-    void screenshotChanged();
-    bool discardChanges();
+    void showOpenImageDialog();
+    void pasteFromClipboard();
+    void pasteEmbeddedFromClipboard();
     void setupImageAnnotator();
     void captureDelayChanged(int delay);
     void addWatermark();
     void showSettingsDialog();
     void showAboutDialog();
     void showScaleDialog();
-	void setPosition(const QPoint &lastPosition);
+	void setPosition();
 	void handleGuiStartup();
+	void saveClicked();
+	void saveAsClicked();
+	void updateApplicationTitle();
+	void capturePostProcessing();
+	void loadImage(const CaptureDto &capture);
+	void loadImageFromFile(const QString &path);
+	void sessionFinished();
+	void captureCanceled();
+	void showPinWindow();
+	void hideMainWindowIfRequired();
 };
 
 #endif // KSNIP_MAINWINDOW_H
