@@ -55,7 +55,7 @@
     </message>
     <message>
         <source>Please add a Watermark Image via Options &gt; Settings &gt; Annotator &gt; Update</source>
-        <translation>Bitte fügen Sie ein Bild für das Wasserzeichen via  Optionen &gt; Einstellungen &gt; Annotator &gt; Aktualisieren hinzu</translation>
+        <translation>Bitte fügen Sie ein Bild für das Wasserzeichen via Optionen &gt; Einstellungen &gt; Annotator &gt; Aktualisieren hinzu</translation>
     </message>
 </context>
 <context>
@@ -138,39 +138,21 @@ macht sie glatter.</translation>
         <source>Annotator Settings</source>
         <translation>Beschriftungseinstellungen</translation>
     </message>
+    <message>
+        <source>Remember annotation tool selection and load on startup</source>
+        <translation>Merke Auswahl des Beschriftungstool und stelle diese beim Starten wieder her</translation>
+    </message>
+    <message>
+        <source>Switch to Select Tool after drawing Item</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ApplicationSettings</name>
-    <message>
-        <source>Always copy capture to clipboard</source>
-        <translation>Aufnahme immer in die Zwischenablage kopieren</translation>
-    </message>
-    <message>
-        <source>Prompt to save before discarding unsaved changes</source>
-        <translation>Aufforderung zum Speichern, bevor nicht gespeicherte Änderungen verworfen werden</translation>
-    </message>
-    <message>
-        <source>Save ksnip position on move and load on startup</source>
-        <translation>Ksnip-Position beim Verschieben speichern und beim Starten laden</translation>
-    </message>
-    <message>
-        <source>Save ksnip tool selection and load on startup</source>
-        <translation>Ksnip-Werkzeugauswahl speichern und beim Starten laden</translation>
-    </message>
     <message>
         <source>Capture screenshot at startup with default mode</source>
         <translation>Beim Starten Screenshot im Standardmodus aufnehmen</translation>
     </message>
-    <message>
-        <source>Instant save to default location without &apos;Save as&apos; dialog</source>
-        <translation>Sofort am Standardspeicherort speichern, ohne &quot;Speichern unter&quot;-Dialog zu öffnen</translation>
-    </message>
-    <message>
-        <source>When enabled, will not ask where to save a screenshot
-when saving, but will save instantly to default location.</source>
-        <translation>Wenn aktiviert, wird nicht gefragt, wo ein Screenshot gespeichert werden soll,
-sondern speichert sofort am Standardspeicherort.</translation>
-    </message>
     <message>
         <source>Application Style</source>
         <translation>Anwendungsstil</translation>
@@ -181,26 +163,10 @@ Change requires ksnip restart to take effect.</source>
         <translation>Setzt den Anwendungsstil, welcher das Aussehen des GUIs definiert.
 Eine Änderung benötigt einen Neustart von ksnip, um wirksam zu werden.</translation>
     </message>
-    <message>
-        <source>Capture save location and filename</source>
-        <translation>Speicherort und Dateiname für Aufnahmen</translation>
-    </message>
-    <message>
-        <source>Filename can contain $Y, $M, $D for date, $h, $m, $s for time, or $T for time in hhmmss format.</source>
-        <translation>Dateiname kann $Y, $M, $D für Datum, $h, $m, $s für Zeit oder $T für Zeit im hhmmss-Format enthalten.</translation>
-    </message>
-    <message>
-        <source>Browse</source>
-        <translation>Durchsuchen</translation>
-    </message>
     <message>
         <source>Application Settings</source>
         <translation>Anwendungseinstellungen</translation>
     </message>
-    <message>
-        <source>Capture save location</source>
-        <translation>Speicherort für Aufnahmen</translation>
-    </message>
     <message>
         <source>Use Tray Icon</source>
         <translation>Tray Icon verwenden</translation>
@@ -220,19 +186,57 @@ Diese Änderung erfordert einen Neustart.</translation>
         <translation>Zum Tray schließen</translation>
     </message>
     <message>
-        <source>Start Minimized to Tray.</source>
-        <translation>Beim System-Start zum Tray minimieren.</translation>
+        <source>Automatically copy new captures to clipboard</source>
+        <translation>Neue Aufnahmen automatisch in die Zwischenablage kopieren</translation>
+    </message>
+    <message>
+        <source>Auto Hide Tabs</source>
+        <translation>Tabs automatisch ausblenden</translation>
+    </message>
+    <message>
+        <source>Use Tabs</source>
+        <translation>Tabs verwenden</translation>
+    </message>
+    <message>
+        <source>Change requires restart.</source>
+        <translation>Änderung erfordert Neustart.</translation>
+    </message>
+    <message>
+        <source>Run ksnip as single instance</source>
+        <translation>Nur eine Instanz von ksnip starten</translation>
+    </message>
+    <message>
+        <source>Start Minimized to Tray</source>
+        <translation>Im Tray minimiert starten</translation>
+    </message>
+    <message>
+        <source>Hide Tabbar when only one Tab is used.</source>
+        <translation>Tableiste verstecken wenn nur ein Tab offen ist.</translation>
+    </message>
+    <message>
+        <source>Enabling this option will allow only one ksnip instance to run,
+all other instances started after the first will pass its
+arguments to the first and close. Changing this option requires
+a new start of all instances.</source>
+        <translation>Mit dieser Option wird das Ausführen von nur einer ksnip-Instanz erlaubt,
+alle weiteren Instanzen werden ihre Argumente an die zuerst gestartete
+Instanz übergeben und sich wieder schließen. Eine Änderung dieser
+Einstellung erfordert einen Neustartet aller Instanzen.</translation>
+    </message>
+    <message>
+        <source>Remember Main Window position on move and load on startup</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>AuthorTab</name>
     <message>
         <source>The Author:</source>
-        <translation type="unfinished">Der Autor:</translation>
+        <translation>Der Autor:</translation>
     </message>
     <message>
         <source>Contributors:</source>
-        <translation type="unfinished">Mitwirkende:</translation>
+        <translation>Mitwirkenden:</translation>
     </message>
     <message>
         <source>Spanish Translation</source>
@@ -258,6 +262,14 @@ Diese Änderung erfordert einen Neustart.</translation>
         <source>Polish Translation</source>
         <translation>Polnische Übersetzung</translation>
     </message>
+    <message>
+        <source>Snap &amp; Flatpak Support</source>
+        <translation>Snap- und Flatpak-Support</translation>
+    </message>
+    <message>
+        <source>Feature Implementation</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>CanDiscardOperation</name>
@@ -266,10 +278,10 @@ Diese Änderung erfordert einen Neustart.</translation>
         <translation>Warnung - </translation>
     </message>
     <message>
-        <source>The capture has been modified.
+        <source>The capture %1%2%3 has been modified.
 Do you want to save it?</source>
-        <translation>Die Aufnahme wurde geändert.
-Möchten Sie sie speichern?</translation>
+        <translation>Die Bildschirmaufnahme %1%2%3 wurde verändert.
+Speichern?</translation>
     </message>
 </context>
 <context>
@@ -326,40 +338,34 @@ Möchten Sie sie speichern?</translation>
         <source>Capture a screenshot of the last selected rectangular area</source>
         <translation>Einen Screenshot des zuletzt ausgewählten rechteckigen Bereichs aufnehmen</translation>
     </message>
+    <message>
+        <source>Screenshot Portal</source>
+        <translation>Screenshot-Portal</translation>
+    </message>
+    <message>
+        <source>Uses the screenshot Portal for taking screenshot</source>
+        <translation>Verwendet Screenshot Portal um Bildschirmaufnahmen zu erstellen</translation>
+    </message>
 </context>
 <context>
-    <name>CaptureUploader</name>
+    <name>DeleteImageOperation</name>
     <message>
-        <source>Upload to imgur.com finished!</source>
-        <translation>Hochladen zu imgur.com abgeschlossen!</translation>
+        <source>Delete Image</source>
+        <translation>Bild löschen</translation>
     </message>
     <message>
-        <source>Received new token, trying upload again…</source>
-        <translation>Neues Token erhalten, versuche erneut hochzuladen …</translation>
-    </message>
-    <message>
-        <source>Imgur token has expired, requesting new token…</source>
-        <translation>Das Imgur-Token ist abgelaufen, fordere neues Token an …</translation>
+        <source>The item &apos;%1&apos; will be deleted.
+Do you want to continue?</source>
+        <translation>Das Objekt &apos;%1&apos; wird gelöscht.
+Wollen Sie Fortfahren?</translation>
     </message>
 </context>
 <context>
     <name>DonateTab</name>
-    <message>
-        <source>Donate a Beer?</source>
-        <translation>Spendieren Sie mir ein Bier?</translation>
-    </message>
-    <message>
-        <source>Sure, you can do that</source>
-        <translation>Sicher können Sie das machen</translation>
-    </message>
     <message>
         <source>here</source>
         <translation>hier</translation>
     </message>
-    <message>
-        <source>Become a Sponsor</source>
-        <translation>Sponsor werden</translation>
-    </message>
     <message>
         <source>Also possible, </source>
         <translation>Auch möglich, </translation>
@@ -368,16 +374,80 @@ Möchten Sie sie speichern?</translation>
         <source>Donations are always welcome</source>
         <translation>Spenden sind immer willkommen</translation>
     </message>
+    <message>
+        <source>Donation</source>
+        <translation>Spende</translation>
+    </message>
+    <message>
+        <source>Become a GitHub Sponsor</source>
+        <translation>GitHub Sponsor werden</translation>
+    </message>
+    <message>
+        <source>ksnip is a non-profitable copylefted libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
+        <translation>ksnip ist ein unkommerzielles, freies und unter „Copyleft“ stehendes Softwareprojekt, &lt;br/&gt;für das jedoch Kosten anfallen, die es zu decken gilt,&lt;br/&gt; wie z.B. Kosten für die Internetdomäne oder Hardwarekosten für die plattformübergreifende Unterstützung.</translation>
+    </message>
+    <message>
+        <source>If you want to help or just&lt;br/&gt;want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that</source>
+        <translation>Falls du helfen möchtest oder &lt;br/&gt;deine Wertschätzung für die Arbeit ausdrücken möchtest&lt;br/&gt;, indem du den Entwicklern ein Bier oder Kaffee ausgeben möchtest, kannst du das gerne tun</translation>
+    </message>
 </context>
 <context>
-    <name>HandleUploadResponseOperation</name>
+    <name>HandleUploadResultOperation</name>
     <message>
         <source>Upload Successful</source>
         <translation>Erfolgreich hochgeladen</translation>
     </message>
+    <message>
+        <source>Upload script </source>
+        <translation>Script hochladen </translation>
+    </message>
+    <message>
+        <source> finished successfully.</source>
+        <translation> erfolgreich abgeschlossen.</translation>
+    </message>
     <message>
         <source>Uploaded to</source>
-        <translation>Hochgeladen zu</translation>
+        <translation type="unfinished">Hochgeladen zu</translation>
+    </message>
+    <message>
+        <source>Unable to save temporary image for upload.</source>
+        <translation>Temporäres Bild kann nicht zum Hochladen gespeichert werden.</translation>
+    </message>
+    <message>
+        <source>Unable to start process, check path and permissions.</source>
+        <translation>Starten des Prozesses nicht möglich, prüfen Sie Pfad und Berechtigungen.</translation>
+    </message>
+    <message>
+        <source>Process crashed</source>
+        <translation>Prozess abgestürzt</translation>
+    </message>
+    <message>
+        <source>Process timed out.</source>
+        <translation>Der Prozess hat ein Timeout erreicht.</translation>
+    </message>
+    <message>
+        <source>Process read error.</source>
+        <translation>Prozesslesefehler.</translation>
+    </message>
+    <message>
+        <source>Process write error.</source>
+        <translation>Prozessschreibfehler.</translation>
+    </message>
+    <message>
+        <source>Web error, check console output.</source>
+        <translation>Web-Fehler, Konsolenausgabe prüfen.</translation>
+    </message>
+    <message>
+        <source>Unknown process error.</source>
+        <translation>Unbekannter Prozess-Fehler.</translation>
+    </message>
+    <message>
+        <source>Upload Failed</source>
+        <translation>Hochladen fehlgeschlagen</translation>
+    </message>
+    <message>
+        <source>Script wrote to StdErr.</source>
+        <translation>Script hat in die Fehlerausgabe (StdErr) geschrieben.</translation>
     </message>
 </context>
 <context>
@@ -418,6 +488,14 @@ Möchten Sie sie speichern?</translation>
         <source>Capture Last Rect Area</source>
         <translation>Letzten rechteckigen Bereich aufnehmen</translation>
     </message>
+    <message>
+        <source>Clear</source>
+        <translation>Leeren</translation>
+    </message>
+    <message>
+        <source>Capture using Portal</source>
+        <translation>Aufnahme über Portal</translation>
+    </message>
 </context>
 <context>
     <name>ImageGrabberSettings</name>
@@ -444,8 +522,8 @@ Screenshots sichtbar sein soll.</translation>
 the background image. This option only works
 with &apos;Freeze Image while snipping&apos; enabled.</source>
         <translation>Zeigt eine Lupe an, welche in das Hintergrundbild
-hineinzoomt. Diese Option  funktioniert nur, wenn
-&apos;Bild während der Aufnahme einfrieren&apos; aktiviert wurde.</translation>
+hineinzoomt. Diese Option funktioniert nur, wenn
+„Bild während der Aufnahme einfrieren“ aktiviert wurde.</translation>
     </message>
     <message>
         <source>Show Snipping Area rulers</source>
@@ -461,40 +539,14 @@ Bildschirmrand zum Mauszeiger anzeigen.</translation>
         <source>Show Snipping Area position and size info</source>
         <translation>Position und Größe des Ausschnittsbereichs anzeigen</translation>
     </message>
-    <message>
-        <source>When left mouse is not pressed the position
-is show, when the mouse button is pressed,
-the size of the select area is shown left
-and above from the captured area.</source>
-        <translation>Solange die linke Maustaste noch nicht gedrückt wurde, wird
-die Mausposition angezeigt. Nachdem die linke Maustaste
-gedrückt wurde, wird die Größe des ausgewählten Bereichs
-an dessen linken und oberen Rand angezeigt.</translation>
-    </message>
     <message>
         <source>Snipping Area cursor color</source>
         <translation>Ausschnittsbereich Mauszeigerfarbe</translation>
     </message>
-    <message>
-        <source>Sets the color of the snipping area
-cursor. Change requires ksnip restart to
-take effect.</source>
-        <translation>Legt die Farbe des Mauszeigers bei der Aufnahme eines
-rechteckigen Bereichs fest. Eine Änderung erfordert einen
-Neustart von ksnip, um wirksam zu werden.</translation>
-    </message>
     <message>
         <source>Snipping Area cursor thickness</source>
         <translation>Ausschnittsbereich Mauszeigerstärke</translation>
     </message>
-    <message>
-        <source>Sets the thickness of the snipping area
-cursor. Change requires ksnip restart to
-take effect.</source>
-        <translation>Legt die Stärke des Mauszeigers bei der Aufnahme eines
-rechteckigen Bereiches fest. Eine Änderung erfordert einen
-Neustart von ksnip, um wirksam zu werden.</translation>
-    </message>
     <message>
         <source>Image Grabber</source>
         <translation type="unfinished">Bildgrabber</translation>
@@ -504,10 +556,95 @@ Neustart von ksnip, um wirksam zu werden.</translation>
 selecting a rectangular region. It also changes
 the behavior of delayed screenshots, with this
 option enabled the delay happens before the
-snipping area is show and with the option disabled
+snipping area is shown and with the option disabled
 the delay happens after the snipping area is shown.
 This feature is always disabled for Wayland and always
 enabled for MacOs.</source>
+        <translation>Ist diese Option gesetzt, wird der Hintergrund
+eingefroren und eine rechteckige Auswahl kann
+getroffen werden. Sie wirkt sicht auch auf verzögerte
+Screenshots aus; aktiviert, passiert die Verzögerung
+bevor die Auswahl getroffen werden kann; deaktviert,
+geschieht die Verzögerung, nachdem die Auswahl
+getroffen wurde. Diese Option ist unter Wayland stets
+deaktiviert, unter macOS stets aktiviert.</translation>
+    </message>
+    <message>
+        <source>When left mouse button is not pressed the position
+is shown, when the mouse button is pressed,
+the size of the select area is shown left
+and above from the captured area.</source>
+        <translation>Wenn der Mauszeiger nicht gedrückt wird, wird die
+Position angezeigt; wenn der Mauszeiger gedrückt wird,
+wird die größe des markierten Bereichs links und oberhalb
+des Ausschnittsbereichs angezeigt.</translation>
+    </message>
+    <message>
+        <source>Force Generic Wayland Screenshot</source>
+        <translation>Erzwinge Screenshot über eine standardmäßige Wayland-Funktion</translation>
+    </message>
+    <message>
+        <source>Scale Generic Wayland Screenshots</source>
+        <translation>Skaliere Screenshots über eine standardmäßige Wayland-Funktion</translation>
+    </message>
+    <message>
+        <source>Generic Wayland implementations that use
+XDG-DESKTOP-PORTAL handle screen scaling
+differently. Enabling this option will
+determine the current screen scaling and
+apply that to the screenshot in ksnip.</source>
+        <translation>Standardmäßige Wayland-Implementationen, die
+XDG-DESKTOP-PORTAL verwenden, handhaben
+die Bildschirmskalierung unterschiedlich. Wird diese
+Option aktiviert, wird die aktuelle Bildschirmskalierung
+ermittelt und auf den Screenshot in ksnip angewendet.</translation>
+    </message>
+    <message>
+        <source>GNOME and KDE Plasma support their own Wayland
+and the Generic XDG-DESKTOP-PORTAL screenshots.
+Enabling this option will force KDE Plasma and
+GNOME to use the XDG-DESKTOP-PORTAL screenshots.
+Change in this option require a ksnip restart.</source>
+        <translation>GNOME und KDE Plasma unterstützen sowohl eigene Wayland- als
+auch die standardmäßigen XDG-DESKTOP-PORTAL-Screenshots.
+Wird diese Option aktiviert, werden KDE Plasma und GNOME gezwungen,
+XDG-DESKTOP-PORTAL-Screenshots zu verwenden. Eine Änderung
+dieser Option erfordert einen Neustart von ksnip.</translation>
+    </message>
+    <message>
+        <source>Show Main Window after capturing screenshot</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show Main Window after capturing a new screenshot
+when the Main Window was hidden or minimized.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Allow resizing rect area selection</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>When enabled will, after selecting a rect
+area, allow resizing the selection. When
+done resizing the selection can be confirmed
+by pressing return.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hide Main Window during screenshot</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hide Main Window when capturing a new screenshot.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sets the color of the snipping area cursor.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sets the thickness of the snipping area cursor.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -534,6 +671,21 @@ enabled for MacOs.</source>
         <translation>Löschlink</translation>
     </message>
 </context>
+<context>
+    <name>ImgurUploader</name>
+    <message>
+        <source>Upload to imgur.com finished!</source>
+        <translation>Hochladen zu imgur.com abgeschlossen!</translation>
+    </message>
+    <message>
+        <source>Received new token, trying upload again…</source>
+        <translation>Neues Token erhalten, versuche erneut hochzuladen …</translation>
+    </message>
+    <message>
+        <source>Imgur token has expired, requesting new token…</source>
+        <translation>Das Imgur-Token ist abgelaufen, fordere neues Token an …</translation>
+    </message>
+</context>
 <context>
     <name>ImgurUploaderSettings</name>
     <message>
@@ -544,10 +696,6 @@ enabled for MacOs.</source>
         <source>Always copy Imgur link to clipboard</source>
         <translation>Imgur-Link immer in die Zwischenablage kopieren</translation>
     </message>
-    <message>
-        <source>Ask for confirmation before uploading</source>
-        <translation>Vor dem Hochladen nach Bestätigung fragen</translation>
-    </message>
     <message>
         <source>Client ID</source>
         <translation>Client-ID</translation>
@@ -602,12 +750,22 @@ enabled for MacOs.</source>
     </message>
     <message>
         <source>After uploading open Imgur link in default browser</source>
-        <translation>Nach dem Upload Imgur-Link im Standardbrowser öffnen</translation>
+        <translation>Nach dem Hochladen Imgur-Link im Standardbrowser öffnen</translation>
     </message>
     <message>
         <source>Link directly to image</source>
         <translation>Direkt zum Bild verlinken</translation>
     </message>
+    <message>
+        <source>Base Url:</source>
+        <translation>Basis-URL:</translation>
+    </message>
+    <message>
+        <source>Base url that will be used for communication with Imgur.
+Changing requires restart.</source>
+        <translation>Basis-URL, die für Kommunikation mit Imgur verwendet wird.
+Änderung erfordert Neustart.</translation>
+    </message>
 </context>
 <context>
     <name>MainToolBar</name>
@@ -618,9 +776,8 @@ enabled for MacOs.</source>
     <message>
         <source>Delay in seconds between triggering
 and capturing screenshot.</source>
-        <translation>Zeitverzögerung in Sekunden zwischen
-dem Anstoßen der Bildschirmaufnahme
-und der Aufnahme.</translation>
+        <translation>Zeitverzögerung in Sekunden zwischen dem Auslösen
+und der Aufnahme des Bildschirmfotos.</translation>
     </message>
     <message>
         <source>s</source>
@@ -673,10 +830,6 @@ und der Aufnahme.</translation>
         <source>Upload</source>
         <translation>Hochladen</translation>
     </message>
-    <message>
-        <source>Upload capture image to imgur.com</source>
-        <translation>Bildschirmaufnahme zu imgur.com hochladen</translation>
-    </message>
     <message>
         <source>Print</source>
         <translation>Drucken</translation>
@@ -729,10 +882,6 @@ und der Aufnahme.</translation>
         <source>&amp;Help</source>
         <translation>&amp;Hilfe</translation>
     </message>
-    <message>
-        <source>Open Image</source>
-        <translation>Bild öffnen</translation>
-    </message>
     <message>
         <source>Image Files (*.png *.jpg *.bmp)</source>
         <translation>Bilddateien (* .png * .jpg * .bmp)</translation>
@@ -754,8 +903,143 @@ und der Aufnahme.</translation>
         <translation>Bild kann nicht angezeigt werden</translation>
     </message>
     <message>
-        <source>No image provided to but one was expected.</source>
-        <translation>Es wurde kein Bild zur Verfügung gestellt, obwohl eines erwartet wurde.</translation>
+        <source>Save As...</source>
+        <translation>Speichern als…</translation>
+    </message>
+    <message>
+        <source>Paste</source>
+        <translation>Einfügen</translation>
+    </message>
+    <message>
+        <source>Paste Embedded</source>
+        <translation>Eingebettet einfügen</translation>
+    </message>
+    <message>
+        <source>Upload capture to external source</source>
+        <translation>Lade die Aufnahme auf eine externe Quelle hoch</translation>
+    </message>
+    <message>
+        <source>Pin</source>
+        <translation>Anheften</translation>
+    </message>
+    <message>
+        <source>Pin screenshot to foreground in frameless window</source>
+        <translation>Hefte Screenshot am Vordergrund in einem rahmenlosen Fenster an</translation>
+    </message>
+    <message>
+        <source>No image provided but one was expected.</source>
+        <translation>Kein Bild geliefert, obwohl eines erwartet wurde.</translation>
+    </message>
+    <message>
+        <source>Copy Path</source>
+        <translation type="unfinished">Pfad kopieren</translation>
+    </message>
+    <message>
+        <source>Open Directory</source>
+        <translation>Verzeichnis öffnen</translation>
+    </message>
+    <message>
+        <source>&amp;View</source>
+        <translation>&amp;Anzeigen</translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation>Löschen</translation>
+    </message>
+    <message>
+        <source>Rename</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Open Images</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>MultiCaptureHandler</name>
+    <message>
+        <source>Save</source>
+        <translation type="unfinished">Speichern</translation>
+    </message>
+    <message>
+        <source>Save As</source>
+        <translation type="unfinished">Speichern als</translation>
+    </message>
+    <message>
+        <source>Open Directory</source>
+        <translation>Verzeichnis öffnen</translation>
+    </message>
+    <message>
+        <source>Copy</source>
+        <translation type="unfinished">Kopieren</translation>
+    </message>
+    <message>
+        <source>Copy Path</source>
+        <translation>Pfad kopieren</translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation>Löschen</translation>
+    </message>
+    <message>
+        <source>Rename</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>NewCaptureNameProvider</name>
+    <message>
+        <source>Capture</source>
+        <translation>Aufnahme</translation>
+    </message>
+</context>
+<context>
+    <name>PinWindow</name>
+    <message>
+        <source>Close</source>
+        <translation type="unfinished">Schließen</translation>
+    </message>
+    <message>
+        <source>Close Other</source>
+        <translation>Andere schließen</translation>
+    </message>
+    <message>
+        <source>Close All</source>
+        <translation>Alles schließen</translation>
+    </message>
+</context>
+<context>
+    <name>PinWindowHandler</name>
+    <message>
+        <source>Pin Window %1</source>
+        <translation>Hefte Fenster %1 an</translation>
+    </message>
+</context>
+<context>
+    <name>RenameOperation</name>
+    <message>
+        <source>Image Renamed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Successfully renamed image to </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Image Rename Failed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed to rename image to </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rename image</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>New filename:</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -789,6 +1073,120 @@ und der Aufnahme.</translation>
         <translation>Speicherung fehlgeschlagen unter</translation>
     </message>
 </context>
+<context>
+    <name>SaverSettings</name>
+    <message>
+        <source>Automatically save new captures to default location</source>
+        <translation>Neue Aufnahmen automatisch im Standardverzeichnis speichern</translation>
+    </message>
+    <message>
+        <source>Prompt to save before discarding unsaved changes</source>
+        <translation type="unfinished">Aufforderung zum Speichern, bevor nicht gespeicherte Änderungen verworfen werden</translation>
+    </message>
+    <message>
+        <source>Remember last Save Directory</source>
+        <translation>Zuletzt verwendeten Speicherort merken</translation>
+    </message>
+    <message>
+        <source>When enabled will overwrite the save directory stored in settings
+with the latest save directory, for every save.</source>
+        <translation>Ist diese Option gesetzt, wird das in den Einstellungen gesetzte Verzeichnis zum Abspeichern
+bei jedem Speichern ignoriert und durch das zuletzt benutzte Speicherverzeichnis ersetzt.</translation>
+    </message>
+    <message>
+        <source>Capture save location and filename</source>
+        <translation type="unfinished">Speicherort und Dateiname für Aufnahmen</translation>
+    </message>
+    <message>
+        <source>Supported Formats are JPG, PNG and BMP. If no format provided, PNG will be used as default.
+Filename can contain following wildcards:
+- $Y, $M, $D for date, $h, $m, $s for time, or $T for time in hhmmss format.
+- Multiple consecutive # for counter. #### will result in 0001, next capture would be 0002.</source>
+        <translation>Unterstützte Formate sind JPG, PNG und BMP. Wenn kein Format angegeben wird, wird standardmäßig PNG benutzt.
+Dateinamen können die folgenden Platzhalter verwenden:
+-$Y, $M, $D für das Datum, $h, $m, $s für die Uhrzeit, oder $T für die Zeit im Format hhmmss.
+- mehrere aufeinanderfolgende # als Zähler. #### ergibt 0001, der darauffolgende Screenshot wäre 0002.</translation>
+    </message>
+    <message>
+        <source>Browse</source>
+        <translation type="unfinished">Durchsuchen</translation>
+    </message>
+    <message>
+        <source>Saver Settings</source>
+        <translation>Speichereinstellungen</translation>
+    </message>
+    <message>
+        <source>Capture save location</source>
+        <translation type="unfinished">Speicherort für Aufnahmen</translation>
+    </message>
+    <message>
+        <source>Default</source>
+        <translation>Standard</translation>
+    </message>
+    <message>
+        <source>Factor</source>
+        <translation>Faktor</translation>
+    </message>
+    <message>
+        <source>Save Quality</source>
+        <translation>Speicherqualität</translation>
+    </message>
+    <message>
+        <source>Specify 0 to obtain small compressed files, 100 for large uncompressed files.
+Not all image formats support the full range, JPEG does.</source>
+        <translation>0 angeben, um kleine komprimierte Dateien zu erhalten, 100 für große unkomprimierte Dateien.
+Nicht alle Bildformate unterstützen die gesamte Bandbreite, JPEG schon.</translation>
+    </message>
+</context>
+<context>
+    <name>ScriptUploaderSettings</name>
+    <message>
+        <source>Copy script output to clipboard</source>
+        <translation>Skriptausgabe in Zwischenablage kopieren</translation>
+    </message>
+    <message>
+        <source>Script:</source>
+        <translation>Skript:</translation>
+    </message>
+    <message>
+        <source>Path to script that will be called for uploading. During upload the script will be called
+with the path to a temporary png file as a single argument.</source>
+        <translation>Pfad zum Script, das zum Upload aufgerufen wird. Beim Upload wird der Pfad zur temporären
+png-Datei als einziges Argument an das Script übergeben.</translation>
+    </message>
+    <message>
+        <source>Browse</source>
+        <translation type="unfinished">Durchsuchen</translation>
+    </message>
+    <message>
+        <source>Script Uploader</source>
+        <translation>Skriptbasierter Upload</translation>
+    </message>
+    <message>
+        <source>Select Upload Script</source>
+        <translation>Upload-Skript auswählen</translation>
+    </message>
+    <message>
+        <source>Stop when upload script writes to StdErr</source>
+        <translation>Stopp das Skript, wenn es in die Standardfehlerausgabe (StdErr) schreibt</translation>
+    </message>
+    <message>
+        <source>Marks the upload as failed when script writes to StdErr.
+Without this setting errors in the script will be unnoticed.</source>
+        <translation>Markiert den Upload als fehlgeschlagen, wenn das Skript in die Standardfehlerausgabe (StdErr) schreibt.
+Ohne diese Einstellung werden Fehler im Skript möglicherweise nicht bemerkt.</translation>
+    </message>
+    <message>
+        <source>Filter:</source>
+        <translation>Filter:</translation>
+    </message>
+    <message>
+        <source>RegEx Expression. Only copy to clipboard what matches the RegEx Expression.
+When omitted, everything is copied.</source>
+        <translation>Reguläre Ausdrücke. Nur das in die Zwischenablage kopieren, was dem regulären Ausdruck entspricht.
+Alles wird kopiert wenn leer.</translation>
+    </message>
+</context>
 <context>
     <name>SettingsDialog</name>
     <message>
@@ -809,7 +1207,7 @@ und der Aufnahme.</translation>
     </message>
     <message>
         <source>Imgur Uploader</source>
-        <translation>Imgur Hochlader</translation>
+        <translation>Imgur-Uploader</translation>
     </message>
     <message>
         <source>Application</source>
@@ -823,6 +1221,57 @@ und der Aufnahme.</translation>
         <source>HotKeys</source>
         <translation>Tastenkürzel</translation>
     </message>
+    <message>
+        <source>Uploader</source>
+        <translation>Uploader</translation>
+    </message>
+    <message>
+        <source>Script Uploader</source>
+        <translation>Skriptbasierter Upload</translation>
+    </message>
+    <message>
+        <source>Saver</source>
+        <translation>Speichern</translation>
+    </message>
+    <message>
+        <source>Stickers</source>
+        <translation>Aufkleber</translation>
+    </message>
+</context>
+<context>
+    <name>StickerSettings</name>
+    <message>
+        <source>Up</source>
+        <translation>Hoch</translation>
+    </message>
+    <message>
+        <source>Down</source>
+        <translation>Runter</translation>
+    </message>
+    <message>
+        <source>Use Default Stickers</source>
+        <translation>Standard-Aufkleber nutzen</translation>
+    </message>
+    <message>
+        <source>Sticker Settings</source>
+        <translation>Aufkleber-Einstellungen</translation>
+    </message>
+    <message>
+        <source>Vector Image Files (*.svg)</source>
+        <translation>Vektorgrafik-Dateien (*.svg)</translation>
+    </message>
+    <message>
+        <source>Add</source>
+        <translation>Hinzufügen</translation>
+    </message>
+    <message>
+        <source>Remove</source>
+        <translation>Entfernen</translation>
+    </message>
+    <message>
+        <source>Add Stickers</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>TrayIcon</name>
@@ -849,12 +1298,43 @@ und der Aufnahme.</translation>
 <context>
     <name>UploadOperation</name>
     <message>
-        <source>Imgur Upload</source>
-        <translation>Hochladen bei Imgur</translation>
+        <source>Upload Script Required</source>
+        <translation>Upload-Skript erforderlich</translation>
     </message>
     <message>
-        <source>You are about to upload the screenshot to a imgur.com, do you want to proceed?</source>
-        <translation>Sie sind im Begriff, den Screenshot zu imgur.com hochzuladen, möchten Sie fortfahren?</translation>
+        <source>Please add an upload script via Options &gt; Settings &gt; Upload Script</source>
+        <translation>Bitte füge ein Upload-Skript über Optionen &gt; Einstellungen &gt; Upload-Skript hinzu</translation>
+    </message>
+    <message>
+        <source>Capture Upload</source>
+        <translation>Aufnahme hochladen</translation>
+    </message>
+    <message>
+        <source>You are about to upload the image to an external destination, do you want to proceed?</source>
+        <translation>Du bist dabei das Bild zu einem externen Ziel hochzuladen, möchtest Du fortfahren?</translation>
+    </message>
+</context>
+<context>
+    <name>UploaderSettings</name>
+    <message>
+        <source>Ask for confirmation before uploading</source>
+        <translation type="unfinished">Vor dem Hochladen nach Bestätigung fragen</translation>
+    </message>
+    <message>
+        <source>Uploader Type:</source>
+        <translation>Upload-Typ:</translation>
+    </message>
+    <message>
+        <source>Imgur</source>
+        <translation>Imgur</translation>
+    </message>
+    <message>
+        <source>Script</source>
+        <translation>Skript</translation>
+    </message>
+    <message>
+        <source>Uploader</source>
+        <translation>Uploader</translation>
     </message>
 </context>
 <context>
